; extensions/Receptionist.inc
; file included into extensions.conf to implement contexts
; - [Receptionist]		which screens incoming calls according to callerID and time-of-day, 
; - [Handset]			which sets/resets the External Call Forward Number, and connects to voicemail
; - [ExternalCallForward]	which bridges incoming calls to an external telephone number

; This is a stripped-down and modified version of the dialplan that I run on my IP04 PBX.
; While I have editied this to ensure that the dialplan works with Asterisk x.y on a
; Raspberry Pi, removed a number of irrelevant bells and whistles, and fixed a few unexpected
; bugs, I have not endeavoured to redesign or refactor the code. I recognize that this code
; has redundancies and uses some "workarounds" that may no longer be necessary.

; Originally written for Asterisk 1.4, this dialplan manages incoming and outgoing calls.
; Incoming calls run through a "receptionist" filter that manages calls based on an 
; owner-managed list of known CallerIDs, a set of owner-managed call schedules, and a set
; of owner-managed call settings.  This dialplan DOES NOT INCLUDE a mechanism to manage
; these "owner-managed" entities; I use an Asterisk AMI interface driven by a set of PHP
; web pages and backed by a MySQL database to manage them. I leave it up to you to determine
; how YOU want to manage these entities. You may just use the rasterisk command to "database put"
; new values, or you can build something more sophisticated, like a dialplan extension
; or an AMI interface.

; Requires GLOBAL variables	
;	HANDSET		as the sip.conf account for the attached SIP handset
;	OUTSIDE		as the sip.conf account for the outside SIP line
;	MAILBOX		as the voicemail mailbox that we save msgs in
;	MORNING		as the time interval during which you want callers to hear the GoodMorning greeting
;	AFTERNOON	as the time interval during which you want callers to hear the GoodAfternoon greeting
;	EVENING		as the time interval during which you want callers to hear the GoodEvening greeting

; Channel Variables used by this dialplan
;	WHO		unique ID tying known caller to various resources, key to AstDB /CallerID/* entries
;			and to Receptionist/KnownCallers/* audio files
;	TREATMENT	specified which sort of caller we are dealing with, used to derive NO_IVR, POLICY, and ACCEPT_MSG
;			  MASTER - known caller, accepted always, given extra privileges
;			  DIRECT - known caller, accepted always, no extra privileges
;			  SCREEN - known caller, accepted outside of "Personal Hours", no extra privileges
;			  FILTER - known caller, accepted inside of "Business Hours", no extra privileges
;			  CALLER - unknown caller, accepted inside of "Business Hours", no extra privileges
;			  VMONLY - known caller, refused always, offered voicemail, no extra privileges
;			  REFUSE - known caller, refused always, not offered voicemail, no extra privileges
;	NO_IVR		controls whether to play the SIT or not
;			  0 - do not play the SIT (usual setting for known, acceptable callers)
;			  1 - play the SIT	  (usual setting for unknown callers, known, refused callers)
;	POLICY		controls how we normally handle the caller
;			  0 - refuse the call
;			  1 - check schedule, ring call through to HANDSET
;			  2 - check schedule, ring call through to HANDSET or ECFN
;	ACCEPT_MSG	controls whether we offer to take a voicemail or not
;			  0 - do not offer to accept voicemail
;			  1 - offer to accept voicemail
;	PSLOTS		maximum number of schedule entries in the "Personal Hours" schedule
;	BSLOTS		maximum number of schedule entries in the "Business Hours" schedule
;	ENABLED		indicates whether the schedule entry is enabled or not
;	STIME		selects the time-of-day period that the schedule entry applies to
;	SDOW		selects the day-of-week period that the schedule entry applies to
;	NUMENABLED	internal count of number of enabled Business Hours schedule entries
;	SAVEDPOLICY	internal save area for POLICY while checking Personal Hours schedule
;	RefusedReason	text value stored in CDR UserField, indicates /why/ the context refused the caller
;			  /Declined	acceptable caller otherwise declined because of schedule
;			  /Refused	unacceptable caller ("REFUSE")
;	ECFN		the External Call Forward Number, a phone number
;	TARGET		the Channel to which the call will be sent (either the HANDSET channel, or the local ecfn channel)

; Uses AstDB entries
;	CallerId/*			as the CallerHandling key, derived from the callers CALLERID(num)
;	CallerHandling/AUTOREFUSE	as the default caller TREATMENT for callers refused by callername
;	CallerHandling/*		as the caller TREATMENT for callers identified by CallerId/${CALLERID(num}
;	Settings/Hpolicy		as the default SIT/POLICY/VOICEMAIL values for callers identified as "MASTER"
;	Settings/Dpolicy		as the default SIT/POLICY/VOICEMAIL values for callers identified as "DIRECT"
;	Settings/Ppolicy		as the default SIT/POLICY/VOICEMAIL values for callers identified as "SCREEN"
;	Settings/Bpolicy		as the default SIT/POLICY/VOICEMAIL values for callers identified as "FILTER"
;	Settings/Upolicy		as the default SIT/POLICY/VOICEMAIL values for callers identified as "CALLER"
;	Settings/ScheduleSlots		as the counts of both "Personal hours" and "Business hours" schedule entries
;	Settings/Pschedule*		as the individual "Personal hours" schedule entries
;	Settings/Bschedule*		as the individual "Business hours" schedule entries
;	Settings/ECFN			as the telephone number to forward accepted incoming calls to

; Uses sound files
;	Receptionist/GoodMorning		initial greeting played during MORNING
;	Receptionist/GoodAfternoon		initial greeting played during AFTERNOON
;	Receptionist/GoodEvening		initial greeting played during EVENING
;	Receptionist/Greeting			additional greeting played always, identifies us to caller
;	Receptionist/Not-accepting-calls	played when we decline a call due to policy (blacklisted, etc)
;	Receptionist/StopCalling		randomly played to blacklisted callers 
;	Receptionist/Ringthrough		played when receptionist accepts and rings caller through
;	Receptionist/Noone-available		played when no one answers the call that receptionist rang through
;	Receptionist/Leave-message		invites the caller to leave a voicemail (if policy allows)
;	Receptionist/Goodbye			says goodbye to the caller
;
;	Receptionist/EnterCallFwdNumber		Asks for a number to forward calls to (External Call Forwarding)
;	Receptionist/NoCallForwardEntered	You didn't enter a call forward number when asked
;	Receptionist/CallForwardSet		We confirm the new call forward number
;	Receptionist/CallForwardUnchanged	We advise that we didnt change the stored ECFN
;	Receptionist/CallForwardCancelled	We confirm that External Call Forwarding is cancelled
;
;	Receptionist/KnownCaller/*		individualized greetings for known callers


; Uses dialplan MACRO
;	macro-Accepted				sets CDR userfield when rang through call is picked up
;============================================================================================

[macro-Accepted]				; used in the Dial() invocation
exten => s,1,Set(CDR(userfield)="/Accepted")	; CDR will show that we accepted the call
;============================================================================================

[Receptionist]	
exten = s,1,NoOp(context to screen incoming calls)
; ---------------------------------------------------
; *     BEGIN SPECIAL CASE FOR BLOCKED CALLERIDs    *
; ------------------------------------------------------------------
exten = s,n,Set(NO_IVR=1)					; PLAY the SIT to deter telemarketers
exten = s,n,Set(POLICY=0)					; DO NOT accept the call
exten = s,n,Set(ACCEPT_MSG=0)					; DO NOT accept voicemail
exten = s,n,Set(TREATMENT=REFUSE)				; Set for reporting purposes
exten = s,n,GotoIf($[${ISNULL(${CALLERID(num)})}]?rGotSettings)	; refuse BLOCKED ID calls
; ***** END SPECIAL CASE FOR BLOCKED CALLERIDs    *****

;Use CallerID to retrieve the corresponding WHO and TREATMENT
exten = s,n,NoOp(Retrieve WHO and TREATMENT)
exten = s,n,Set(TREATMENT=CALLER)
exten = s,n,Set(WHO=${DB(CallerId/${CALLERID(num)})})
exten = s,n,ExecIf($["${WHO}" != "" ]?Set(TREATMENT=${DB(CallerHandling/${WHO}))}))

; At this point, we have retrieved a TREATMENT for this CallerID

; ------------------------------------------------------------------
; *     BEGIN SPECIAL CASE FOR ViciDial telemarketer autodialer    *
; ------------------------------------------------------------------
;We AUTOREFUSE callers with CallerId ~ /V[0-9]+/ and no established TREATMENT
;  as we have established that such calls are generated by the ViciDial
;  callcentre/CRM product (http://www.vicidial.org/) used by many telemarketers.
;NOTE:	rAutoRefuse will not only refuse the call, it will record that decision
;	in a new AstDB CallerId/${CALLERID(num)} entry, in order to continue
;	to refuse the caller even if they change their CallerId(name)
;ALSO:	the call handling parameters are carried over from the "Blocked CallerID" handling
;ALSO:	you can extend this to handle other bad-actor callers by CallerID "name"
exten = s,n,NoOp(Process settings for known-by-name bad-actor callers)
exten = s,n,GosubIf($[$[${TREATMENT} = CALLER] & ${REGEX("^V[0-9]+" ${CALLERID(name)})} ]?rAutoRefuse)
; ***** END SPECIAL CASE  FOR ViciDial telemarketer *****

; Now, handle call based on TREATMENT and associated schedule(s)

; REFUSE: We answer and decline calls from blacklisted callerids
;NB: the call handling parameters are carried over from the "Blocked CallerID" handling
exten = s,n,NoOp(Process settings for REFUSE)
exten = s,n,GotoIf($[${TREATMENT} = REFUSE]?rGotSettings)

; VMONLY: We answer and only take voicemail from these callers
;NB: Except for NO_IVR and ACCEPT_MSG, the call handling parameters
;	carry over from the "Blocked CallerID" handling
exten = s,n,NoOp(Process settings for VMONLY)
exten = s,n,Set(NO_IVR=0)					; DONT play the SIT
exten = s,n,Set(ACCEPT_MSG=1)					; Accept voicemail
exten = s,n,GotoIf($[${TREATMENT} = VMONLY]?rGotSettings)

; Get schedule slot counts, clear MusicOnHold in prep for call decisions 
exten = s,n,SET(ARRAY(PSLOTS,BSLOTS)=${DB(Settings/ScheduleSlots)})

; FILTER: Handle "business hours" caller
exten = s,n,NoOp(Process settings for "business hours" caller)
exten = s,n,Set(ARRAY(NO_IVR,POLICY,ACCEPT_MSG)=${DB(Settings/Bpolicy)})
exten = s,n,GosubIf($[${POLICY} > 0]?rBschedule)
exten = s,n,GotoIf($[${TREATMENT} = FILTER]?rGotSettings)

; SCREEN: Handle "personal hours" caller
exten = s,n,NoOp(Process settings for "personal hours" caller)
exten = s,n,Set(ARRAY(NO_IVR,POLICY,ACCEPT_MSG)=${DB(Settings/Ppolicy)})
exten = s,n,GosubIf($[${POLICY} > 0]?rPschedule)
exten = s,n,GotoIf($[${TREATMENT} = SCREEN]?rGotSettings)

; DIRECT: Handle "any time" caller
exten = s,n,NoOp(Process settings for "any time" caller)
exten = s,n,Set(ARRAY(NO_IVR,POLICY,ACCEPT_MSG)=${DB(Settings/Dpolicy)})
exten = s,n,GotoIf($[${TREATMENT} = DIRECT]?rGotSettings)

; MASTER: Handle "privileged" caller
exten = s,n,NoOp(Process settings for "privileged" caller)
exten = s,n,Set(ARRAY(NO_IVR,POLICY,ACCEPT_MSG)=${DB(Settings/Hpolicy)})
exten = s,n,GotoIf($[${TREATMENT} = MASTER]?rGotSettings)

; other: Handle as "Unknown" Caller and pass given (probably "CALLER") TREATMENT on to reporting
exten = s,n,NoOp(Process settings for "unknown" caller)
exten = s,n,ExecIf($[${TREATMENT} != CALLER ]?Verbose(FIXME: TREATMENT has unexpected value <${TREATMENT}>))
exten = s,n,Set(ARRAY(NO_IVR,POLICY,ACCEPT_MSG)=${DB(Settings/Upolicy)})
exten = s,n,GosubIf($[${POLICY} > 0]?rBschedule)
;<<fall through to rGotSettings>>

;	-----------------
;	| rGotSettings	| Answer and handle the incoming call
;	-----------------------------------------------------
exten = s,n(rGotSettings),NoOp(Got NO_IVR, POLICY and ACCEPT_MSG values)
exten = s,n,GosubIf($[${POLICY} = 0]?rSetRefusedReason)		; When "REFUSE CALL", update CDR(userfield)
exten = s,n,Answer(500)
exten = s,n,GosubIf($[${NO_IVR} = 1]?rPlaySIT)
exten = s,n,Gosub(rGreeting)					; Greet the caller
exten = s,n,GosubIf($[${POLICY} > 0]?rAcceptCall:rRefuseCall)	; Accept or Refuse the call
exten = s,n,GosubIf($[${ACCEPT_MSG} = 1]?rTakeMsg)		; conditionally offer to accept voicemail
exten = s,n,Playback(Receptionist/Goodbye)				; "Thank you for calling. Goodbye."
exten = s,n,Wait(1)
exten = s,n,Hangup

;	-----------------
;	| rBschedule	| "BUSINESS HOURS" schedule
;	--------------------------------------------
exten = s,n(rBschedule),NoOp(Get call decision by BUSINESS HOURS schedule)
exten = s,n,Gosub(rPschedule)							;Set default POLICY using our "PERSONAL HOURS" schedule
exten = s,n,Set(NUMENABLED=0)							;count of enabled schedules
exten = s,n,Set(IX=0)								;start with first Bschedule
exten = s,n,While($[${IX} < ${BSLOTS}])						;loop until all potential schedules tested
exten = s,n,GotoIf(${ISNULL(${DB(Settings/Bschedule${IX})})}?nextUsched)	;  SKIP if schedule doesn't exist
exten = s,n,Set(ARRAY(ENABLED,STIME,SDOW)=${DB(Settings/Bschedule${IX})})	;  get schedule particulars
exten = s,n,GotoIf(${ISNULL(${ENABLED})}?nextUsched)				;  SKIP if schedule missing the enable flag
exten = s,n,GotoIf($[${ENABLED} != A ]?nextUsched)				;  SKIP if schedule not enabled
exten = s,n,Set(NUMENABLED=$[${NUMENABLED}+1])					;  count off one enabled schedule
exten = s,n,ExecIfTime(${STIME},${SDOW},*,*?Return)				;  EXIT (default) if within a schedule interval
exten = s,n(nextUsched),Set(IX=$[${IX}+1])					;  advance to next schedule
exten = s,n,EndWhile								;back to top of the loop
exten = s,n,ExecIf($[${NUMENABLED} > 0]?Set(POLICY=0))				;REFUSE the call ONLY if we have business hours
exten = s,n,Return								;return decision

;	-----------------
;	| rPschedule	| "PERSONAL HOURS" schedule
;	--------------------------------------------
exten = s,n(rPschedule),NoOp(Get call decision by PERSONAL HOURS schedule)
exten = s,n,Set(SAVEDPOLICY=${POLICY})						;Save the initial policy to use on ACCEPT
exten = s,n,Set(POLICY=0)							;Assume REFUSE call
exten = s,n,Set(IX=0)								;start with first Pschedule
exten = s,n,While($[${IX} < ${PSLOTS}])						;loop until all potential schedules tested
exten = s,n,GotoIf(${ISNULL(${DB(Settings/Pschedule${IX})})}?nextIsched)	;  SKIP ifschedule doesn't exist
exten = s,n,Set(ARRAY(ENABLED,STIME,SDOW)=${DB(Settings/Pschedule${IX})})	;  get schedule particulars
exten = s,n,GotoIf(${ISNULL(${ENABLED})}?nextIsched)				;  SKIP if schedule missing the enable flag
exten = s,n,GotoIf($[${ENABLED} != A ]?nextIsched)				;  SKIP if schedule not enabled
exten = s,n,ExecIfTime(${STIME},${SDOW},*,*?Return)				;  EXIT (REFUSE) if within the schedule interval
exten = s,n(nextIsched),Set(IX=$[${IX}+1])					;  advance to next schedule
exten = s,n,EndWhile								;back to top of loop
exten = s,n,Set(POLICY=${SAVEDPOLICY})						;ACCEPT the call with original POLICY
exten = s,n,Return()								;return decision

;	-----------------
;	| rAutoRefuse	|
;	--------------------------------------------
exten = s,n(rAutoRefuse),NoOp(Set TREATMENT, CallerHandling for autorefused caller)
exten = s,n,Set(DB(CallerId/${CALLERID(num)})=AUTOREFUSE)	; future calls will get "AUTOREFUSE" WHO and associated TREATMENT
exten = s,n,Set(TREATMENT=${DB(CallerHandling/AUTOREFUSE)})	; this call gets whatever TREATMENT the AUTOREFUSE WHO says
exten = s,n,Return()

;	-------------------------
;	| rSetRefusedReason	|
;	--------------------------------------------
exten = s,n(rSetRefusedReason),NoOp(Set CDR userfield with reason for not accepting call)
exten = s,n,Set(RefusedReason="Declined")						;otherwise acceptable caller called at the wrong time
exten = s,n,ExecIf($["${TREATMENT}" = "VMONLY" ]?Set(RefusedReason="Refused"))		;Voicemail Only Caller
exten = s,n,ExecIf($["${TREATMENT}" = "REFUSE" ]?Set(RefusedReason="Refused"))		;Blacklisted Caller
exten = s,n,Set(CDR(userfield)="/${RefusedReason}")
exten = s,n,Return()

;	-----------------
;	| rPlaySIT	|
;	--------------------------------------------
exten = s,n(rPlaySIT),NoOp(Receptionist will play the "Out of Service" SIT)
exten = s,n,Zapateller()	;"Out of Service" Special Information Tone
exten = s,n,Wait(0.3)
exten = s,n,Return()

;	-----------------
;	| rGreeting	|
;	--------------------------------------------
exten = s,n(rGreeting),NoOp(Receptionist will greet the caller)
exten = s,n,ExecIfTime(${MORNING},*,*,*?Playback(Receptionist/GoodMorning))		; "Good Morning"
exten = s,n,ExecIfTime(${AFTERNOON},*,*,*?Playback(Receptionist/GoodAfternoon))	; "Good Afternoon"
exten = s,n,ExecIfTime(${EVENING},*,*,*?Playback(Receptionist/GoodEvening))		; "Good Evening"
exten = s,n,Playback(Receptionist/KnownCallers/${WHO})					; Try to greet caller by name
exten = s,n,ExecIf($[${PLAYBACKSTATUS} != SUCCESS]?Playback(Receptionist/Greeting))	; No name, use generic greeting
exten = s,n,Wait(0.3)								; pause a bit more
exten = s,n,ExecIf($["${TREATMENT}" != "REFUSE" ]?WaitForSilence(500))		; Polite wait for friends and strangers
exten = s,n,Return()

;	-----------------
;	| rAcceptCall	|
;	--------------------------------------------
exten = s,n(rAcceptCall),NoOp(Receptionist will accept the call)
exten = s,n,Set(ECFN=${DB(Settings/ECFN)})		; avoids race conditions on possible db update
exten = s,n,Set(TARGET="${HANDSET}")			; default route all incoming calls to the HANDSET
exten = s,n,ExecIf($[$[${POLICY}=2]&$[${LEN(${ECFN})} > 0]]?Set(TARGET="Local/${ECFN}@ExternalCallForward/n"))	;callforward trick
exten = s,n,Playback(Receptionist/Ringthrough)			; "I will ring you through."
exten = s,n,Wait(0.5)
exten = s,n,Dial(${TARGET},20,M(Accepted))
exten = s,n,Wait(0.5)
exten = s,n,Playback(Receptionist/Noone-available)		; "We cannot handle your call at this time."
exten = s,n,Return()

;	-----------------
;	| rRefuseCall	|
;	----------------------------------------------
exten = s,n(rRefuseCall),NoOp(Receptionist will decline the call)
exten = s,n,Playback(Receptionist/Not-accepting-calls)		; "We are not accepting calls at this time."
exten = s,n,ExecIf($[$[${TREATMENT} = REFUSE] & $[${RAND(0(3))}=0]]?Playback(Receptionist/StopCalling))
exten = s,n,Return()

;	-----------------
;	| rTakeMsg	|
;	----------------------------------------------
exten = s,n(rTakeMsg),NoOp(Receptionist will take a message)
exten = s,n,Wait(1)
exten = s,n,Playback(Receptionist/Leave-message)			; "Please leave a message."
exten = s,n,Wait(1)
exten = s,n,Voicemail(${MAILBOX},s)
exten = s,n,Return()

;----------
;# Hangup #
;----------------------------------------------
exten = h,1,NoOp(Caller hung up)
exten = h,n,ExecIf($["${VMSTATUS}" = "SUCCESS" ]?Set(CDR(userfield))=${CDR(userfield))}/Voicemail))
;====================================================================================

[ExternalCallForward]	; bridge incoming call to specified outside phone number
exten = _X.,1,NoOp(Call Forward to ${EXTEN})
exten = _X.,n,Set(CDR(userfield) = /CallForward)
exten = _X.,n,Set(CDR(amaflags) = BILLING)
exten = _X.,n,Dial(${OUTSIDE}/${EXTEN})
exten = _X.,n,Hangup()
;====================================================================================

[Handset]
; Note:	SIP will Urlencode dialed numbers, so "#1" is seen by the dialplan as %231
;	Telephone handsets (using DAHDI, if you have the equipment) dial #1 as #1
; First, the URLencoded extensions for SIP handsets

exten = %230,1,NoOp(Urlencoded "#0" - retrieve Voicemail)
exten = %230,n,VoiceMailMain(s${MAILBOX})
exten = %230,n,Hangup

exten = %231,1,NoOp(Urlencoded "#1" - Enable External Call Forward)
exten = %231,n,Playback(Receptionist/EnterCallFwdNumber)			; "Please dial the number to forward calls too"
exten = %231,n,Read(ECFN,,10)							; accepts up to 10 digits
exten = %231,n,GosubIf($[${ISNULL(${ECFN})}]?NoNumber:SetNumber)		; no number supplied, abort. Otherwise set number
exten = %231,n,Wait(1)
exten = %231,n,Hangup()								; and that's it
exten = %231,n(SetNumber),NoOp(Save external call forward number)		; --------- Set ECFN -------------
exten = %231,n,Set(DB(Settings/ECFN)=${ECFN})					; store entered number in Settings/ECFN
exten = %231,n,Playback(Receptionist/CallForwardSet)				; "Incoming call forwarding has been set to"
exten = %231,n,SayDigits(${ECFN})						; this number
exten = %231,n,Return								; done
exten = %231,n(NoNumber),NoOp(No external call forward number entered)		; ---------- No ECFN entered -----------
exten = %231,n,Playback(Receptionist/NoCallForwardEntered)			; "No call forward number was entered"
exten = %231,n,Playback(Receptionist/CallForwardUnchanged)			; "Incoming call forwarding is not changed."
exten = %231,n,Return								; done

exten = %232,1,NoOp(Urlencoded "#2" - Disable External Call Forward)		; --------- Clear ECFN -------------
exten = %232,n,Set(DB(Settings/ECFN)=)						; clear stored number
exten = %232,n,Playback(Receptionist/CallForwardCancelled)			; "Incoming Call forwarding is cancelled."
exten = %232,n,Wait(1)
exten = %232,n,Hangup()								; done

; Next, the plain extensions for regular telephone handsets
exten = #0,1,NoOp(plain #0 - retrieve Voicemail)
exten = #0,n,VoiceMailMain(s${MAILBOX})
exten = #0,n,Hangup

exten = #1,1,NoOp(plain "#1" - Enable External Call Forward)
exten = #1,n,Playback(Receptionist/EnterCallFwdNumber)				; "Please dial the number to forward calls too"
exten = #1,n,Read(ECFN,,10)							; accepts up to 10 digits
exten = #1,n,GosubIf($[${ISNULL(${ECFN})}]?NoNumber:SetNumber)			; no number supplied, abort. Otherwise set number
exten = #1,n,Wait(1)
exten = #1,n,Hangup()								; and that's it
exten = #1,n(SetNumber),NoOp(Save external call forward number)			; --------- Set ECFN -------------
exten = #1,n,Set(DB(Settings/ECFN)=${ECFN})					; store entered number in Settings/ECFN
exten = #1,n,Playback(Receptionist/CallForwardSet)				; "Incoming call forwarding has been set to"
exten = #1,n,SayDigits(${ECFN})							; this number
exten = #1,n,Return								; done
exten = #1,n(NoNumber),NoOp(No external call forward number entered)		; ---------- No ECFN entered -----------
exten = #1,n,Playback(Receptionist/NoCallForwardEntered)			; "No call forward number was entered"
exten = #1,n,Playback(Receptionist/CallForwardUnchanged)			; "Incoming call forwarding is not changed."
exten = #1,n,Return								; done

exten = #2,1,NoOp(plain "#2" - Disable External Call Forward)			; --------- Clear ECFN -------------
exten = #2,n,Set(DB(Settings/ECFN)="")						; clear stored number
exten = #2,n,Playback(Receptionist/CallForwardCancelled)			; "Incoming Call forwarding is cancelled."
exten = #2,n,Wait(1)
exten = #2,n,Hangup()								; done
;====================================================================================

;	Copyright (c) Lew Pitcher <lew.pitcher@digitalfreehold.ca> 2014-2020
;
;	This program is free software; you can redistribute it and/or modify
;	it under the terms of the GNU General Public License as published by
;	the Free Software Foundation; either version 2 of the License, or
;	(at your option) any later version.
;
;	This program is distributed in the hope that it will be useful,
;	but WITHOUT ANY WARRANTY; without even the implied warranty of
;	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;	GNU General Public License for more details.
;
;	You should have received a copy of the GNU General Public License along
;	with this program; if not, write to the Free Software Foundation, Inc.,
;	51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
